@@ -1,5 +1,5 @@
 """
-Drawing and plotting routines for IGraph.
+Drawing and plotting routines for igraph.
 
 Plotting is dependent on the C{pycairo} or C{cairocffi} libraries that provide
 Python bindings to the popular U{Cairo library<http://www.cairographics.org>}.
@@ -42,7 +42,7 @@ cairo = find_cairo()
 #####################################################################
 
 
-class Plot(object):
+class Plot:
     """Class representing an arbitrary plot
 
     Every plot has an associated surface object where the plotting is done. The
@@ -312,13 +312,13 @@ class Plot(object):
     def show(self):
         """Saves the plot to a temporary file and shows it.
 
-        This method is deprecated from python-igraph 0.9.1 and will be removed in
+        This method is deprecated from igraph 0.9.1 and will be removed in
         version 0.10.0.
 
         @deprecated: Opening an image viewer with a temporary file never worked
             reliably across platforms.
         """
-        warn("Plot.show() is deprecated from python-igraph 0.9.1", DeprecationWarning)
+        warn("Plot.show() is deprecated from igraph 0.9.1", DeprecationWarning)
 
         if not isinstance(self._surface, cairo.ImageSurface):
             sur = cairo.ImageSurface(
@@ -369,12 +369,7 @@ class Plot(object):
         context.show_page()
         surface.finish()
         # Return the raw SVG representation
-        result = io.getvalue()
-        if hasattr(result, "encode"):
-            result = result.encode("utf-8")  # for Python 2.x
-        else:
-            result = result.decode("utf-8")  # for Python 3.x
-
+        result = io.getvalue().decode("utf-8")
         return result, {"isolated": True}  # put it inside an iframe
 
     @property
@@ -431,8 +426,8 @@ def plot(obj, target=None, bbox=(0, 0, 600, 600), *args, **kwds):
 
         - C{None} -- a temporary file will be created and the object will be
           plotted there. igraph will attempt to open an image viewer and show
-          the temporary file. This feature is deprecated from python-igraph
-          version 0.9.1 and will be removed in 0.10.0.
+          the temporary file. This feature is deprecated from igraph version
+          0.9.1 and will be removed in 0.10.0.
 
     @param bbox: the bounding box of the plot. It must be a tuple with either
       two or four integers, or a L{BoundingBox} object. If this is a tuple
